%% This function predicts the Shear Capcity of Steel Fiber Reinforced Concrete Beams
%% based on the pretrained NN-RCGA model.
%
%% Compatible with Matlab 2010 or higher
%
clear all
close all
clc
%
%% Preparation of inputs:
% Load preset of data:
Data = xlsread('Dataset_test.xlsx');
%
% List of random sampling
number_random = round(unifrnd(1, size(Data, 1), 1, 1));
index_selected = randperm(size(Data, 1));
% 
Inputs = Data(index_selected(1:number_random), 1:16);
Targets = Data(index_selected(1:number_random), 17);
%
%%
% Input vector in the real space
X = Inputs;
%
%% Scaling of data: see also Table in the manuscript
ScaledParameters = [[50 100 85.2500000000000 204 102 52.4000000000000 0.00374068706659994 275.862068965517 0.695652173913044 0.412598425196850 0.400000000000000 9.77000000000000 0.200000000000000 25 260 0.0750000000000000 12824.4600000000];
    [310 1000 910 5600 2800 2700 0.0572090328870620 900 6 5.95348837209302 22 215 4.50000000000000 190.500000000000 4913 2.85750000000000 396000]];
% Input vector in the scaling space:
X_scaled = (X - ScaledParameters(1, 1:16))./(ScaledParameters(2, 1:16) - ScaledParameters(1, 1:16));

%% Evaluation of the pretrained AI Prediction Model
% Load pretrained NN-RCGA model:
load pretrained_NN_RCGA_model.mat

%% Prediction of shear capacity:
SC_predicted_scaled = net(X_scaled');

%% Reverse mode of normalization of output
SC_predicted = SC_predicted_scaled.*(ScaledParameters(2, 17) - ScaledParameters(1, 17)) + ScaledParameters(1, 17);
SC_predicted = SC_predicted';
%% Evalutation compared to expected data: compute correlation coefficient
[r1,~,~] = regression(Targets,SC_predicted,'one');
errorR = r1(1);
%% Plot of results
figure;
hold on
plot([min([Targets; SC_predicted]) max([Targets; SC_predicted])], [min([Targets; SC_predicted]) max([Targets; SC_predicted])], 'k:', 'LineWidth', 3)
plot(Targets, SC_predicted, 'square', 'MarkerSize', 4, 'MarkerFaceColor', 'k', 'LineWidth', 1)
p_train = polyfit(Targets, SC_predicted, 1);
plot([min([Targets; SC_predicted]) max([Targets; SC_predicted])], [p_train(1)*(min([Targets; SC_predicted]))+p_train(2) p_train(1)*(max([Targets; SC_predicted]))+p_train(2)], 'm', 'LineWidth', 1)
grid on
box on
axis square
xlabel('Actual data (N)', 'FontSize', 16, 'FontWeight', 'Bold', 'FontName', 'Times New Roman')
ylabel('Predicted data (N)', 'FontSize', 16, 'FontWeight', 'Bold', 'FontName', 'Times New Roman')
set(gca, 'FontSize', 16, 'FontWeight', 'Bold', 'FontName', 'Times New Roman')
leg = legend('Ideal fit', ['R=', num2str(round(errorR*1000)/1000)], 'Linear fit');
set(leg, 'FontWeight', 'Bold', 'FontSize', 12, 'FontName', 'TimeNewsRoman')
set(leg, 'Location', 'NorthWest')
title('Shear capacity')


